@@ -8,6 +8,8 @@ Pod::Readme - generate README files from POD
 
 =head1 SYNOPSIS
 
+In a module's POD:
+
   =head1 NAME
 
   MyApp - my nifty app
@@ -34,10 +36,30 @@ Pod::Readme - generate README files from POD
 
   ...
 
+Then from the command-line:
+
+  pod2readme lib/MyModule.pm README
+
+=for readme stop
+
+From within Perl:
+
+  use Pod::Readme;
+
+  my $prf = Pod::Readme->new(
+    input_file		=> 'lib/MyModule.pm',
+    translate_to_file	=> $dest,
+    translation_class	=> 'Pod::Simple::Text',
+  );
+
+  $prf->run();
+
+=for readme start
+
 =head1 DESCRIPTION
 
 This module filters POD to generate a F<README> file, by using POD
-commands to specify what parts of included or excluded from the
+commands to specify which parts are included or excluded from the
 F<README> file.
 
 =begin :readme
@@ -47,7 +69,12 @@ syntax that this module recognizes.
 
 See L<pod2readme> for command-line usage.
 
-=for readme plugin requires
+=head1 INSTALLATION
+
+See
+L<How to install CPAN modules|http://www.cpan.org/modules/INSTALL.html>.
+
+=for readme plugin requires heading-level=2 title="Required Modules"
 
 =for readme plugin changes
 
@@ -70,7 +97,7 @@ Start (or continue to) include the POD that follows in the F<README>.
 Note that the C<start> command was added as a synonym in version
 1.0.0.
 
-=head C<=for readme include>
+=head2 C<=for readme include>
 
   =for readme include file="INSTALL" type="text"
 
@@ -158,7 +185,7 @@ use MooseX::Types::IO 'IO';
 use MooseX::Types::Path::Class;
 use Path::Class;
 
-use version 0.77; our $VERSION = version->declare('v1.0.0_01');
+use version 0.77; our $VERSION = version->declare('v1.0.0_02');
 
 =head1 ATTRIBUTES
 
@@ -197,11 +224,13 @@ has translate_to_fh => (
         my ($self) = @_;
         if ( $self->translate_to_file ) {
             $self->translate_to_file->openw;
-        } else {
+        }
+        else {
             my $fh = IO::Handle->new;
             if ( $fh->fdopen( fileno(STDOUT), 'w' ) ) {
                 return $fh;
-            } else {
+            }
+            else {
                 croak "Cannot get a filehandle for STDOUT";
             }
         }
@@ -216,11 +245,11 @@ then it will be saved to C<STDOUT>.
 =cut
 
 has translate_to_file => (
-    is       => 'ro',
-    isa      => 'Path::Class::File',
-    coerce   => 1,
-    lazy     => 1,
-    builder  => 'default_readme_file',
+    is      => 'ro',
+    isa     => 'Path::Class::File',
+    coerce  => 1,
+    lazy    => 1,
+    builder => 'default_readme_file',
 );
 
 =head2 C<output_file>
@@ -231,18 +260,19 @@ file.
 =cut
 
 has '+output_file' => (
-    lazy => 1,
+    lazy    => 1,
     default => sub {
         my $tmp_dir = dir( $ENV{TMP} || $ENV{TEMP} || '/tmp' );
-        file( ($tmp_dir->tempfile( SUFFIX => '.pod', UNLINK => 1 ))[1] );
+        file( ( $tmp_dir->tempfile( SUFFIX => '.pod', UNLINK => 1 ) )[1] );
     },
 );
 
 around '_build_output_fh' => sub {
-    my ($orig, $self) = @_;
-    if (defined $self->translation_class) {
+    my ( $orig, $self ) = @_;
+    if ( defined $self->translation_class ) {
         $self->$orig();
-    } else {
+    }
+    else {
         $self->translate_to_fh;
     }
 };
@@ -261,7 +291,7 @@ L</translation_class>.
 sub default_readme_file {
     my ($self) = @_;
 
-    my $name = uc($self->target);
+    my $name = uc( $self->target );
 
     state $extensions = {
         'Pod::Man'           => '.1',
@@ -274,15 +304,16 @@ sub default_readme_file {
     };
 
     my $class = $self->translation_class;
-    if (defined $class) {
-        if (my $ext = $extensions->{$class}) {
+    if ( defined $class ) {
+        if ( my $ext = $extensions->{$class} ) {
             $name .= $ext;
         }
-    } else {
+    }
+    else {
         $name .= '.pod';
     }
 
-    file($self->base_dir, $name);
+    file( $self->base_dir, $name );
 }
 
 =head2 C<translate_file>
@@ -294,23 +325,24 @@ This method runs translates the resulting POD from C<filter_file>.
 sub translate_file {
     my ($self) = @_;
 
-    if (my $class = $self->translation_class) {
+    if ( my $class = $self->translation_class ) {
 
         load $class;
         my $converter = $class->new()
-            or croak "Cannot instantiate a ${class} object";
+          or croak "Cannot instantiate a ${class} object";
 
-        if ($converter->isa('Pod::Simple')) {
+        if ( $converter->isa('Pod::Simple') ) {
 
             my $tmp_file = $self->output_file->stringify;
 
             close $self->output_fh
-                or croak "Unable to close file ${tmp_file}";
+              or croak "Unable to close file ${tmp_file}";
 
-            $converter->output_fh($self->translate_to_fh);
-            $converter->parse_file( $tmp_file );
+            $converter->output_fh( $self->translate_to_fh );
+            $converter->parse_file($tmp_file);
 
-        } else {
+        }
+        else {
 
             croak "Don't know how to translate POD using ${class}";
 
@@ -326,11 +358,67 @@ This method runs C<filter_file> and then L</translate_file>.
 =cut
 
 around 'run' => sub {
-    my ($orig, $self) = @_;
+    my ( $orig, $self ) = @_;
     $self->$orig();
     $self->translate_file();
 };
 
+=head2 C<parse_from_file>
+
+  my $parser = Pod::Readme->new();
+  $parser->parse_from_file( 'README.pod', 'README' );
+
+  Pod::Readme->parse_from_file( 'README.pod', 'README' );
+
+This is a class method that acts as a L<Pod::Select> compatability
+shim for software that is designed for versions of L<Pod::Readme>
+prior to v1.0.
+
+Its use is deprecated, and will be deleted in later versions.
+
+=cut
+
+sub parse_from_file {
+    my ( $self, $source, $dest ) = @_;
+
+    my $class = ref($self) || __PACKAGE__;
+    my $prf = $class->new(
+        input_file        => $source,
+        translate_to_file => $dest,
+        translation_class => 'Pod::Simple::Text',
+    );
+    $prf->run();
+}
+
+=head2 C<parse_from_filehandle>
+
+Like L</parse_from_file>, this exists as a compatability shim.
+
+Its use is deprecated, and will be deleted in later versions.
+
+=cut
+
+sub parse_from_filehandle {
+    my ( $self, $source_fh, $dest_fh ) = @_;
+
+    my $class = ref($self) || __PACKAGE__;
+
+    my $src_io =
+      IO::Handle->new_from_fd( ( defined $source_fh ) ? fileno($source_fh) : 0,
+        'r' );
+
+    my $dest_io =
+      IO::Handle->new_from_fd( ( defined $dest_fh ) ? fileno($dest_fh) : 1,
+        'w' );
+
+    my $prf = $class->new(
+        input_fh          => $src_io,
+        translate_to_fh   => $dest_io,
+        translation_class => 'Pod::Simple::Text',
+    );
+    $prf->run();
+}
+
 use namespace::autoclean;
 
 1;
